----------------------------------------------------------------------
-- 	Leatrix Frames 4.2.06
-- 	Last updated: 10th August 2011
----------------------------------------------------------------------

-- 	Create table to store frame layout
	if not LeaFramesDB then LeaFramesDB = {} end

--	Initialise
	local r, g, b = 1.0, 0.85, 0.0
	GhostFrame:Show();

--	Setup dummy functions to replace Blizzards
	local LeaFramesStopDura = DurabilityFrame.SetPoint
	DurabilityFrame.SetPoint = function() end

	local LeaFramesStopVehi = VehicleSeatIndicator.SetPoint
	VehicleSeatIndicator.SetPoint = function() end

	local LeaFramesStopMirror = MirrorTimer1.SetPoint
	MirrorTimer1.SetPoint = function() end

	local LeaFramesStopGhost = GhostFrame.SetPoint
	GhostFrame.SetPoint = function() end

----------------------------------------------------------------------
--	Create drag frames
----------------------------------------------------------------------

--	Functions used for this process
	local function LeaFramesDragMake(LeaFramesDragName,LeaFramesDragText)
		local LeaFramesDragName = CreateFrame("Frame", LeaFramesDragName, UIParent); 
		LeaFramesDragName.text = LeaFramesDragText;
	end

	local function LeaFrameMakeDrag(LeaFrameReal,LeaFrameDrag)
		LeaFrameDrag:SetSize(LeaFrameReal:GetSize())
		LeaFrameDrag:SetPoint("TOP", LeaFrameReal, "TOP", 0, 2.5)
		LeaFrameDrag:EnableMouse(true)
		LeaFrameReal:SetMovable(true)
		LeaFrameReal:SetUserPlaced(true)

		LeaFrameDrag:SetScript("OnMouseDown", function() 
			LeaFrameReal:StartMoving() 
			--x1,x2,x3,x4,x5 = LeaFrameReal:GetPoint()
			--print(x1,x2,x3,x4,x5)
			end)
		LeaFrameDrag:SetScript("OnMouseUp", function()
			LeaFrameReal:StopMovingOrSizing()
			end)

		LeaFrameDrag.t = LeaFrameDrag:CreateTexture()
		LeaFrameDrag.t:SetAllPoints()
		LeaFrameDrag.t:SetTexture(0.0, 0.5, 1.0,0.5)
		LeaFrameDrag:SetBackdropColor(0.0, 0.5, 1.0);
		LeaFrameDrag.t:SetAlpha(0.5)
		LeaFrameDrag:SetBackdrop({ 
			edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
			tile = false, tileSize = 0, edgeSize = 16,
			insets = { left = 0, right = 0, top = 0, bottom = 0 }});
		LeaFrameDrag:Hide()
		LeaFrameDrag:SetToplevel(true)
		LeaWorldPvPDrag:SetSize(300,50)

		local LeaFramesText = LeaFrameDrag:CreateFontString(nil, 'ARTWORK', 'GameFontNormalLarge')
			LeaFramesText:SetPoint('TOPLEFT', 16, -16)
			LeaFramesText:SetText(LeaFrameDrag.text)
	end

--	Create drag frames
	LeaFramesDragMake("LeaPlayerDrag", "Player")
	LeaFramesDragMake("LeaTargetDrag", "Target")
	LeaFramesDragMake("LeaWorldPvPDrag", "World PvP Scores")
	LeaFramesDragMake("LeaPetDrag", "Pet")
	LeaFramesDragMake("LeaGhostDrag", "Ghost")
	LeaFramesDragMake("LeaMirrorDrag", "Mirror Timer")
	LeaFramesDragMake("LeaDuraDrag", "Durability")
	LeaFramesDragMake("LeaVehDrag", "Vehicle")

-- 	Create frame table (ties real frames to drag frames)
	local LeaFrameTable = {
		PlayerFrame = LeaPlayerDrag,
		TargetFrame = LeaTargetDrag,
		WorldStateAlwaysUpFrame = LeaWorldPvPDrag,
		PetFrame = LeaPetDrag,
		GhostFrame = LeaGhostDrag,
		MirrorTimer1 = LeaMirrorDrag,
		DurabilityFrame = LeaDuraDrag,
		VehicleSeatIndicator = LeaVehDrag,
	}

--	Populate the drag frames
	local function LeaFramesCreateDrag()
		for k,v in pairs(LeaFrameTable) do
			LeaFrameMakeDrag(_G[k],v)
		end
	end

----------------------------------------------------------------------
--	Functions
----------------------------------------------------------------------

--	Manually move frames
	local function LeaFramesShow(LeaFramesN, LeaFramesA, LeaFramesR, LeaFramesX, LeaFramesY)
		LeaFramesN:SetMovable(true); LeaFramesN:SetUserPlaced(true); LeaFramesN:ClearAllPoints();
		LeaFramesN:SetPoint(LeaFramesA, UIParent, LeaFramesR, LeaFramesX, LeaFramesY)
	end

--	Check for combat
	local function LeaFramesCombatCheck()
		if (UnitAffectingCombat("player")) then
			DEFAULT_CHAT_FRAME:AddMessage("You cannot do that while in combat.", r,g,b)
			return false;
		else
			return true;
		end
	end

--	Control frame locks (prevent Blizzard from moving frames)
	local function LeaFramesFrameLocks(LeaFramesFrameLocksStatus)
		if LeaFramesFrameLocksStatus == "Open" then
			VehicleSeatIndicator.SetPoint = LeaFramesStopVehi
			DurabilityFrame.SetPoint = LeaFramesStopDura
			MirrorTimer1.SetPoint = LeaFramesStopMirror
			GhostFrame.SetPoint = LeaFramesStopGhost

		elseif LeaFramesFrameLocksStatus == "Close" then
			VehicleSeatIndicator.SetPoint = function() end
			DurabilityFrame.SetPoint = function() end
			MirrorTimer1.SetPoint = function() end
			GhostFrame.SetPoint = function() end

		end
	end

--	Lock and unlock drag frames (for movement)
	local function LeaFramesLock(status)
		if status == "Show" then
			for k,v in pairs(LeaFrameTable) do
				v:Show();
			end
		end
		if status == "Hide" then
			for k,v in pairs(LeaFrameTable) do
				v:Hide();
			end
		end
	end

-- 	Button tooltips
	local function ShowTooltip(self)
		if self.tiptext then
			GameTooltip:SetOwner(self, "ANCHOR_TOP")
			GameTooltip:SetText(self.tiptext, nil, nil, nil, nil, true)
		end
	end

	local function HideTooltip() 
		GameTooltip:Hide() 
	end

--	Save frame layout
	local function LeaFramesSaveGlobal()
		if not LeaFramesCombatCheck() then return end;

		-- Create profile table structure
		if (LeaFramesDB["Profile"]) == nil then
			LeaFramesDB["Profile"] = {}
		end

		-- Store frame layout
		for k,v in pairs(LeaFrameTable) do
			local LeaTempPoint, _,LeaTempRelativePoint, LeaTempXOffset, LeaTempYOffset = _G[k]:GetPoint()
			LeaFramesDB["Profile"][k] = {["Point"] = LeaTempPoint, ["RelativePoint"] = LeaTempRelativePoint, ["XOffset"] = LeaTempXOffset, ["YOffset"] = LeaTempYOffset}
		end
	end

-- 	Set frame locations to Wow defaults
	local function LeaFramesSetDefaults()

		local function LeaFramesSetPos(x0,x1,x2,x3,x4,x5)
			x0:SetMovable(true);
			x0:SetUserPlaced(true); 
			x0:ClearAllPoints();
			x0:SetPoint(x1,x2,x3,x4,x5)
		end

		LeaFramesFrameLocks("Open")
		LeaFramesSetPos(PlayerFrame			,"TOPLEFT",UIParent,"TOPLEFT",-19,-4)
		LeaFramesSetPos(TargetFrame			,"TOPLEFT",UIParent,"TOPLEFT",250,-4)
		LeaFramesSetPos(WorldStateAlwaysUpFrame,"TOP",UIParent,"TOP",-5,-15)
		LeaFramesSetPos(PetFrame			,"TOPLEFT",UIParent,"TOPLEFT",61,-64)
		LeaFramesSetPos(GhostFrame			,"TOP",UIParent,"TOP",-5,-29)
		LeaFramesSetPos(MirrorTimer1		,"TOP",UIParent,"TOP",0,-96)
		LeaFramesSetPos(DurabilityFrame		,"TOPRIGHT",UIParent,"TOPRIGHT",-20,-192)
		LeaFramesSetPos(VehicleSeatIndicator,"TOPRIGHT",UIParent,"TOPRIGHT",40,-177)
		LeaFramesFrameLocks("Close")
		LeaFramesSaveGlobal();
	end

-- 	Restore frame layout
	local function LeaFramesLoadSilent()
		if not LeaFramesCombatCheck() then return end;
		if (LeaFramesDB["Profile"]) then
			LeaFramesFrameLocks("Open")
			for k,v in pairs(LeaFrameTable) do
				if LeaFramesDB["Profile"][k] then
					if LeaFramesDB["Profile"][k]["Point"] and LeaFramesDB["Profile"][k]["RelativePoint"] and LeaFramesDB["Profile"][k]["XOffset"] and LeaFramesDB["Profile"][k]["YOffset"] then
						_G[k]:SetUserPlaced(true);
						_G[k]:ClearAllPoints();
						_G[k]:SetPoint(LeaFramesDB["Profile"][k]["Point"], UIParent, LeaFramesDB["Profile"][k]["RelativePoint"], LeaFramesDB["Profile"][k]["XOffset"], LeaFramesDB["Profile"][k]["YOffset"])
					end
				end
			end
			LeaFramesFrameLocks("Close")
		else
			LeaFramesSetDefaults()
		end
	end

----------------------------------------------------------------------
--	Manual settings (invoked using the manual switch)
----------------------------------------------------------------------

--	Set all frames to manual positions (modify this if you want to)
	local function LeaFramesSetManual()

		if not LeaFramesCombatCheck() then return end;
		LeaFramesFrameLocks("Open")

		-- Modify the block below if you want to, these are the manual settings
		LeaFramesShow(PlayerFrame, "TOPLEFT", "TOPLEFT", "-35", "-14")
		LeaFramesShow(TargetFrame, "TOPLEFT", "TOPLEFT", "192", "-14")
		LeaFramesShow(PetFrame, "TOPLEFT", "TOPLEFT", "80", "10")
		LeaFramesShow(GhostFrame, "CENTER", "CENTER", "2.6799773770574", "-141.60033968687")
		LeaFramesShow(DurabilityFrame, "TOP", "TOP", "212.39993732572", "-138.24001106262")
		LeaFramesShow(WorldStateAlwaysUpFrame, "TOP", "TOP", "-70", "-630")
		LeaFramesShow(MirrorTimer1, "TOP", "TOP", "0", "-120")
		LeaFramesShow(VehicleSeatIndicator, "TOPRIGHT", "TOPRIGHT", "-139.20005590916", "-137.32002053678")
		-- End of the manual block

		LeaFramesFrameLocks("Close")
		LeaFramesSaveGlobal();
		DEFAULT_CHAT_FRAME:AddMessage("Manual settings have been loaded.", r,g,b)
	end

----------------------------------------------------------------------
--	Create frame movement Window
----------------------------------------------------------------------

	-- Create frame movement window
	local LeaFramesMove = CreateFrame("Frame","LeaFrameMoveWarn",UIParent) 
	LeaFramesMove:Hide();
	LeaFramesMove:SetBackdrop(StaticPopup1:GetBackdrop()) 
	LeaFramesMove:SetHeight(170) 
	LeaFramesMove:SetWidth(400) 
	LeaFramesMove:SetToplevel(true)
	LeaFramesMove:ClearAllPoints() 
	LeaFramesMove:SetPoint("CENTER", 0, -70) 
	LeaFramesMove:SetClampedToScreen(false);
	LeaFramesMove:EnableMouse(true)
	LeaFramesMove:SetMovable(true)
	LeaFramesMove:RegisterForDrag("LeftButton")
	LeaFramesMove:SetScript("OnDragStart", LeaFramesMove.StartMoving)
	LeaFramesMove:SetScript("OnDragStop", function ()
		LeaFramesMove:StopMovingOrSizing();
		LeaFramesMove:SetUserPlaced(false);
	end)

	-- Add window text
	local text = LeaFramesMove:CreateFontString(nil, "BACKGROUND", "GameFontNormalLarge") 
	text:SetPoint("TOPLEFT",30,-25) 
	text:SetText("Leatrix Frames")

	local function LeaFramesCheckIt(LeaFramesCheckName,LeaFramesCheckCheck,LeaFramesCheckX,LeaFramesCheckY,LeaFramesCheckMod,LeaFramesCheckTitle,LeaFramesCheckTip)
	local LeaFramesCheckMove = CreateFrame('CheckButton', LeaFramesCheckName, LeaFramesMove, 'ChatConfigCheckButtonTemplate')
		LeaFramesCheckMove:SetChecked(LeaFramesCheckCheck)
		LeaFramesCheckMove:SetPoint("TOPLEFT", LeaFramesCheckX, LeaFramesCheckY)
		LeaFramesCheckMove.tooltip = (LeaFramesCheckTip);
		local text = LeaFramesCheckMove:CreateFontString(nil, "BACKGROUND", "GameTooltipText") 
			text:SetPoint("LEFT",30,0) 
			text:SetText(LeaFramesCheckTitle)
		LeaFramesCheckMove:SetScript('OnClick', function(self)
			if LeaFramesCheckMove:GetChecked() == nil then
				LeaFramesCheckMod:Hide();
			end
			if LeaFramesCheckMove:GetChecked() == 1 then
				LeaFramesCheckMod:Show();
			end					
		end)

		-- Set checkboxes back to true when hidden
		LeaFramesCheckMove:SetScript('OnHide', function(self)
			LeaFramesCheckMove:SetChecked(true);
		end)
	end
	
	-- Add checkboxes
	LeaFramesCheckIt(LeaPlayerDragChk,true,30,-60,LeaPlayerDrag,"Player","Player frame.")
	LeaFramesCheckIt(LeaTargetDragChk,true,30,-80,LeaTargetDrag,"Target","Target frame.")
	LeaFramesCheckIt(LeaPetDragChk,true,30,-100,LeaPetDrag,"Pet","Pet frame.")
	LeaFramesCheckIt(LeaGhostDragChk,true,30,-120,LeaGhostDrag,"Ghost","Return to graveyard button.")

	LeaFramesCheckIt(LeaDuraDragChk,true,200,-60,LeaDuraDrag,"Durability","Durability frame.")
	LeaFramesCheckIt(LeaWorldPvPDragChk,true,200,-80,LeaWorldPvPDrag,"World PvP","World PvP scores")
	LeaFramesCheckIt(LeaMirrorDragChk,true,200,-100,LeaMirrorDrag,"Timer Bar","Timer bars (such as water breathing).")
	LeaFramesCheckIt(LeaVehDragChk,true,200,-120,LeaVehDrag,"Vehicle Seat","Vehicle seat indicator frame.")

	-- Add the save button
	local LeaFramesSave = CreateFrame("Button", "LeaFramesSave", LeaFramesMove, "UIPanelButtonTemplate") 
	LeaFramesSave:SetWidth(80)
	LeaFramesSave:SetHeight(25) 
	LeaFramesSave:SetAlpha(1.0)
	LeaFramesSave:SetPoint("TOPRIGHT", -20, -20)
	LeaFramesSave:SetText("Save") 
	LeaFramesSave.tiptext = "Save your frame layout."
	LeaFramesSave:SetScript("OnEnter", ShowTooltip)		
	LeaFramesSave:SetScript("OnLeave", HideTooltip)
	LeaFramesSave:SetScript("OnClick", function()
		LeaFramesSaveGlobal();
		LeaFramesLock("Hide");
		LeaFramesMove:Hide();
		InterfaceOptionsFrame:Show();
	end)

----------------------------------------------------------------------
--	Events
----------------------------------------------------------------------

--	Create main frames
	local frame = CreateFrame("FRAME", "Leatrix_Frames");
	frame:RegisterEvent("ADDON_LOADED");
	frame:RegisterEvent("VARIABLES_LOADED");
	frame:SetScript("OnEvent", function(self, event, arg1)

		-- When addon has loaded, setup the drag frames.
		if (event == "ADDON_LOADED" and arg1 == "Leatrix_Frames") then
			UIParentLoadAddOn("Blizzard_DebugTools")
			DEFAULT_CHAT_FRAME:AddMessage("Leatrix Frames is ready.", 1.0,0.85,0.0)
			LeaFramesCreateDrag();
		end
		
		if (event == "VARIABLES_LOADED") then

			-- Remove integrated movement functions to avoid conflicts
			PlayerFrame_SetLocked(true)
			PlayerFrame_SetLocked = function()
				DEFAULT_CHAT_FRAME:AddMessage("Please use Leatrix Frames to move the player frame.", 1.0,0.85,0.0)
			end
			TargetFrame_SetLocked(true)
			TargetFrame_SetLocked = function()
				DEFAULT_CHAT_FRAME:AddMessage("Please use Leatrix Frames to move the target frame.", 1.0,0.85,0.0)
			end

			-- Ensure party frame positions aren't saved
			PartyMemberFrame1:SetUserPlaced(false)
			PartyMemberFrame2:SetUserPlaced(false)
			PartyMemberFrame3:SetUserPlaced(false)
			PartyMemberFrame4:SetUserPlaced(false)

			-- Load frame positions
			LeaFramesLoadSilent();

		end

	end)

----------------------------------------------------------------------
-- 	Slash commands
----------------------------------------------------------------------

--	Slash command handler
	local function slashCommand(str)
		if str == '' then
			InterfaceOptionsFrame_OpenToCategory("Leatrix Frames");
		elseif str == 'help' then DEFAULT_CHAT_FRAME:AddMessage("Leatrix Frames\n\n/ltf - Options panel\n/ltf reload - Reload UI\n/ltf frame - Frame information\n/ltf info - Current layout", r,g,b)
		elseif str == "frame" then
			FrameStackTooltip_Toggle();
		elseif str == "reload" then
			ReloadUI();
		elseif str == "manual" then
			LeaFramesSetManual()
		elseif str == "wipe" then
			LeaFramesWipe()
		elseif str == "debug" then
			local LeaDebugFrame = _G["Boss2TargetFrame"]
			local l1,l2,l3,l4,l5 = LeaDebugFrame:GetPoint()
			local l6,l7 = LeaDebugFrame:GetSize()
			local l8 = LeaDebugFrame:GetParent():GetName()
			if (l1) then print("Relative Point: " .. l1) end
			if (l2) then print("Relative: " .. l2:GetName()) end
			if (l3) then print("Relative To: " .. l3) end
			if (l4) then print("X offset: " .. l4) end
			if (l5) then print("Y offset: " .. l5) end
			if (l6) then print("Width: " .. l6) end
			if (l7) then print("Height: " .. l7) end
			if (l8) then print("Parent: " .. l8) end
		elseif str == "info" then
			for k,v in pairs(LeaFrameTable) do
				local LeaFrameInfoT,_,LeaFrameInfoA,LeaFrameInfoX,LeaFrameInfoY = _G[k]:GetPoint();
				DEFAULT_CHAT_FRAME:AddMessage(_G[k]:GetName(), r,g,b);
				DEFAULT_CHAT_FRAME:AddMessage(LeaFrameInfoT .. ", " .. LeaFrameInfoA, r,g,b)
				DEFAULT_CHAT_FRAME:AddMessage(LeaFrameInfoX .. ", " .. LeaFrameInfoY, r,g,b)
				DEFAULT_CHAT_FRAME:AddMessage("------------------", r,g,b)
			end
		else
			DEFAULT_CHAT_FRAME:AddMessage("Invalid command.  Type '/ltf help' for help.",  r,g,b)
		end
	end

--	Slash command support
	SLASH_Leatrix_Frames1 = "/ltf"
	SLASH_Leatrix_Frames2 = "/leaframes"

	SlashCmdList["Leatrix_Frames"] = function(str) slashCommand(string.lower(str)) end

----------------------------------------------------------------------
-- 	Options panel functions
----------------------------------------------------------------------

	-- Define panel title
	local function OptionsTitle(title,subtitle,LeaOptionsFrame)
		local text = LeaOptionsFrame:CreateFontString(nil, 'ARTWORK', 'GameFontNormalLarge')
		text:SetPoint('TOPLEFT', 16, -16)
		text:SetText(title)
			local subtext = LeaOptionsFrame:CreateFontString(nil, 'ARTWORK', 'GameFontHighlightSmall')
		subtext:SetHeight(32)
		subtext:SetPoint('TOPLEFT', text, 'BOTTOMLEFT', 0, -8)
		subtext:SetPoint('RIGHT', LeaOptionsFrame, -32, 0)
		subtext:SetNonSpaceWrap(true)
		subtext:SetJustifyH('LEFT')
		subtext:SetJustifyV('TOP')
		subtext:SetText(subtitle)
	end

	-- Define subheadings
	local function OptionsText(title,x,y,LeaOptionsFrame)
		local text = LeaOptionsFrame:CreateFontString(nil, 'ARTWORK', 'GameFontNormal')
		text:SetPoint("TOPLEFT",x,y)
		text:SetText(title)
	end

	-- Define text
	local function OptionsWords(title,x,y,LeaOptionsFrame)
		local text = LeaOptionsFrame:CreateFontString(nil, 'ARTWORK', 'GameFontHighlight')
		text:SetPoint("TOPLEFT",x,y)
		text:SetText(title)
	end

	-- Define button
	local function LeaFramesButton(name,frm,label,anchor,x,y,width,height,tip)
		local LeaFramesDeflt = CreateFrame("Button", name, frm, "UIPanelButtonTemplate") 
		LeaFramesDeflt:SetWidth(width)
		LeaFramesDeflt:SetHeight(height) 
		LeaFramesDeflt:SetAlpha(1.0)
		LeaFramesDeflt:SetPoint(anchor, x, y)
		LeaFramesDeflt:SetText(label)
		LeaFramesDeflt:RegisterForClicks("AnyUp") 
		LeaFramesDeflt.tiptext = tip
		LeaFramesDeflt:SetScript("OnEnter", ShowTooltip)		
		LeaFramesDeflt:SetScript("OnLeave", HideTooltip)
	end

----------------------------------------------------------------------
-- 	Options panel
----------------------------------------------------------------------

-- 	Define the options panel
	local LeaFramesOpt0 = CreateFrame('Frame', 'LeaFramesOpt0', UIParent)

	function LeaFramesOpt0:OptionsPanel()
		self.name = "Leatrix Frames"

		OptionsTitle("Leatrix Frames",(select(3, GetAddOnInfo("Leatrix_Frames"))),LeaFramesOpt0);
		OptionsText("Welcome to Leatrix Frames.", 16, -72,LeaFramesOpt0);
		OptionsWords("To begin moving frames, click the Modify button below.", 16, -92,LeaFramesOpt0);

		-- Modify button
		LeaFramesButton("LeaFramesModify",LeaFramesOpt0,"Modify","BOTTOMLEFT",10,10,130,25,"Modify the frame layout.")
		LeaFramesModify:SetScript("OnClick", function() 
			if not LeaFramesCombatCheck() then return end;
			InterfaceOptionsFrame:Hide();
			LeaFramesMove:Show();
			LeaFramesLock("Show");
		end)

		-- Reset to defaults button
		LeaFramesButton("LeaFramesReset",LeaFramesOpt0,"Reset","BOTTOMLEFT",140,10,130,25,"Resets all of the frames back to the Wow defaults.")
		LeaFramesReset:SetScript("OnClick", function() 
			if not LeaFramesCombatCheck() then return end;

				-- Show reset warning first
				local LeaFramesText = "Leatrix Frames\n\nAre you sure you want to set your frame layout back to the default values?\n\nWARNING:\nThis will replace your current layout.";
				StaticPopupDialogs["LeaFramesResDefCheck"] = {text = LeaFramesText, sound = "TalentScreenOpen", timeout = 0, hideOnEscape = false, whileDead = 1,

				button1 = "Ok",
				OnAccept = function()
					LeaFramesSetDefaults();
					DEFAULT_CHAT_FRAME:AddMessage("Your frame layout has been reset.", r,g,b)
					InterfaceOptionsFrame:Show();
				end,
				button2 = "Cancel",
				OnCancel = function()
					InterfaceOptionsFrame:Show();
				end};

				InterfaceOptionsFrame:Hide();
				StaticPopup_Show ("LeaFramesResDefCheck");
		end)

		LeaFramesButton("LeaFramesRefresh",LeaFramesOpt0,"Refresh","BOTTOMLEFT",270,10,130,25,"Restores the most recently saved frame layout.")
		LeaFramesRefresh:SetScript("OnClick", function() 
			LeaFramesLoadSilent();
		end)

		-- Add panels to interface options    
		InterfaceOptions_AddCategory(LeaFramesOpt0)
	
	end

	-- 	Show panel
	LeaFramesOpt0:OptionsPanel();
